@@ -13,15 +13,22 @@ module Language.Cimple.Ast
     , CommentStyle (..)
     , Comment
     , CommentF (..)
+    , Nullability (..)
+    , getNodeId
     ) where
 
 import           Data.Aeson                   (FromJSON, FromJSON1, ToJSON,
                                                ToJSON1)
-import           Data.Fix                     (Fix)
+import           Data.Fix                     (Fix (..))
 import           Data.Functor.Classes         (Eq1, Ord1, Read1, Show1)
 import           Data.Functor.Classes.Generic (FunctorClassesDefault (..))
+import           Data.Hashable                (Hashable (..))
+import           Data.Hashable.Lifted         (Hashable1)
 import           GHC.Generics                 (Generic, Generic1)
 
+getNodeId :: Hashable a => Node a -> Int
+getNodeId = hash
+
 data NodeF lexeme a
     -- Preprocessor
     = PreprocInclude lexeme
@@ -73,6 +80,7 @@ data NodeF lexeme a
     | VarDeclStmt a (Maybe a)
     | VarDecl a lexeme [a]
     | DeclSpecArray (Maybe a)
+    | ArrayDim Nullability a
     -- Expressions
     | InitialiserList [a]
     | UnaryExpr UnaryOp a
@@ -110,6 +118,7 @@ data NodeF lexeme a
     | TyNullable a
     | TyPointer a
     | TyStruct lexeme
+    | TyUnion lexeme
     | TyFunc lexeme
     | TyStd lexeme
     | TyUserDefined lexeme
@@ -133,39 +142,34 @@ type Node lexeme = Fix (NodeF lexeme)
 
 instance FromJSON lexeme => FromJSON1 (NodeF lexeme)
 instance ToJSON lexeme => ToJSON1 (NodeF lexeme)
+instance Hashable lexeme => Hashable1 (NodeF lexeme)
 
 data CommentF lexeme a
     = DocComment [a]
-    | DocWord lexeme
-    | DocSentence [a] lexeme
-    | DocNewline
 
-    | DocAttention [a]
-    | DocBrief [a]
-    | DocDeprecated [a]
+    | DocAttention
+    | DocBrief
+    | DocDeprecated
     | DocExtends lexeme
+    | DocFile
     | DocImplements lexeme
-    | DocParam (Maybe lexeme) lexeme [a]
-    | DocReturn [a]
-    | DocRetval lexeme [a]
-    | DocSee lexeme [a]
+    | DocNote
+    | DocParam (Maybe lexeme) lexeme
+    | DocReturn
+    | DocRetval
+    | DocSection lexeme
+    | DocSecurityRank lexeme (Maybe lexeme) lexeme
+    | DocSee lexeme
+    | DocSubsection lexeme
 
     | DocPrivate
 
-    | DocParagraph [a]
     | DocLine [a]
     | DocCode lexeme [a] lexeme
-    | DocList [a]
-    | DocULItem [a] [a]
-    | DocOLItem lexeme [a]
 
-    | DocColon lexeme
+    | DocWord lexeme
     | DocRef lexeme
     | DocP lexeme
-    | DocLParen a
-    | DocRParen a
-    | DocAssignOp AssignOp a a
-    | DocBinaryOp BinaryOp a a
     deriving (Show, Read, Eq, Ord, Generic, Generic1, Functor, Foldable, Traversable)
     deriving (Show1, Read1, Eq1, Ord1) via FunctorClassesDefault (CommentF lexeme)
 
@@ -173,6 +177,7 @@ type Comment lexeme = Fix (CommentF lexeme)
 
 instance FromJSON lexeme => FromJSON1 (CommentF lexeme)
 instance ToJSON lexeme => ToJSON1 (CommentF lexeme)
+instance Hashable lexeme => Hashable1 (CommentF lexeme)
 
 data AssignOp
     = AopEq
@@ -242,6 +247,7 @@ instance ToJSON LiteralType
 data Scope
     = Global
     | Static
+    | Local
     deriving (Enum, Bounded, Ord, Show, Read, Eq, Generic)
 
 instance FromJSON Scope
@@ -257,3 +263,22 @@ data CommentStyle
 
 instance FromJSON CommentStyle
 instance ToJSON CommentStyle
+
+data Nullability
+    = NullabilityUnspecified
+    | Nullable
+    | Nonnull
+    deriving (Enum, Bounded, Ord, Show, Read, Eq, Generic)
+
+instance FromJSON Nullability
+instance ToJSON Nullability
+
+instance (Hashable lexeme, Hashable a) => Hashable (NodeF lexeme a) where
+instance (Hashable lexeme, Hashable a) => Hashable (CommentF lexeme a) where
+instance Hashable AssignOp where
+instance Hashable BinaryOp where
+instance Hashable UnaryOp where
+instance Hashable LiteralType where
+instance Hashable Scope where
+instance Hashable CommentStyle where
+instance Hashable Nullability where
