@@ -4,8 +4,9 @@ module Language.Cimple.Tokens
     ( LexemeClass (..)
     ) where
 
-import           Data.Aeson   (FromJSON, ToJSON)
-import           GHC.Generics (Generic)
+import           Data.Aeson    (FromJSON, ToJSON)
+import           Data.Hashable (Hashable)
+import           GHC.Generics  (Generic)
 
 data LexemeClass
     = IdConst
@@ -109,7 +110,7 @@ data LexemeClass
     | CmtCommand
     | CmtAttr
     | CmtEndDocSection
-    | CmtIndent
+    | CmtSpace
     | CmtStart
     | CmtStartCode
     | CmtStartBlock
@@ -131,3 +132,4 @@ data LexemeClass
 
 instance FromJSON LexemeClass
 instance ToJSON LexemeClass
+instance Hashable LexemeClass
